@@ -64,6 +64,6 @@ def start(address, filter_string=None, no_dns=False):
         filter_string = f"outbound && !loopback && ip.DstAddr != {resolve_address(address)} && ip"
 
     if no_dns:
-        filter_string = f"{filter_string} || udp.DstPort != 53"
+        filter_string = f"outbound && !loopback && ip.DstAddr != {resolve_address(address)} && (tcp || udp.DstPort != 53 || icmp)"
 
     loop.run_until_complete(start_client(address, filter_string))
